(function() {
  var activate, render;

  activate = function(element) {
    var button, clear, disableSaveButton, editor, enableSaveButton, error, field, hideError, hideSaving, input, save, showError, showSaving, trySave;
    field = $(element);
    editor = field.html(render(field.scrivito('content') || ''));
    input = editor.find('input');
    button = editor.find('a');
    error = editor.find('div.scrivito_error');
    clear = editor.find('.scrivito_clear');
    input.on('input', function() {
      var permalink;
      permalink = input.val();
      if (permalink === field.scrivito('content')) {
        hideError();
        return disableSaveButton();
      } else if (permalink.split('/')[0] === 'scrivito') {
        showError('The permalink cannot be "scrivito" or start with "scrivito/".');
        return disableSaveButton();
      } else if (permalink.match(/^([\w._-]+[\/\w._-]*)?$/)) {
        hideError();
        return enableSaveButton();
      } else {
        showError('The permalink may only contain letters from A to Z, periods, hyphens, and underscores.');
        return disableSaveButton();
      }
    });
    clear.on('click', function() {
      input.val('');
      hideError();
      if (!field.scrivito('content')) {
        disableSaveButton();
      } else {
        enableSaveButton();
      }
      return false;
    });
    button.on('click', function() {
      trySave();
      return false;
    });
    editor.on('keyup', function(event) {
      switch (event.keyCode) {
        case 13:
          return trySave();
        case 27:
          input.val(field.scrivito('content'));
          hideError();
          disableSaveButton();
          return input.blur();
      }
    });
    trySave = function() {
      var permalink;
      if (button.hasClass('scrivito_disabled')) {
        return false;
      }
      showSaving();
      permalink = input.val();
      if (permalink) {
        return scrivito.obj_where('_permalink', 'equals', permalink).size().then(function(total) {
          if (total > 0) {
            hideSaving();
            showError('Permalink already taken.');
            disableSaveButton();
            return input.focus();
          } else {
            return save(permalink);
          }
        });
      } else {
        return save(null);
      }
    };
    disableSaveButton = function() {
      return button.addClass('scrivito_disabled');
    };
    enableSaveButton = function() {
      return button.removeClass('scrivito_disabled scrivito_saving');
    };
    showError = function(message) {
      disableSaveButton();
      input.addClass('scrivito_error');
      error.text(message);
      return error.show();
    };
    hideError = function() {
      input.removeClass('scrivito_error');
      return error.hide();
    };
    showSaving = function() {
      input.attr('disabled', 'disabled');
      disableSaveButton();
      button.addClass('scrivito_saving');
      return button.find('span').text('Saving...');
    };
    hideSaving = function() {
      input.removeAttr('disabled');
      enableSaveButton();
      return button.find('span').text('Save');
    };
    return save = function(permalink) {
      return field.scrivito('save', permalink).then(function() {
        return activate(field);
      });
    };
  };

  render = function(content) {
    return "<div class=\"scrivito_permalink_editor\">\n  <input type=\"text\" value=\"" + content + "\" />\n  <span class=\"scrivito_clear\"></span>\n  <a href=\"#\" class=\"scrivito_editing_button scrivito_disabled\">\n    <span>Save</span>\n  </a>\n  <div class=\"scrivito_error\"></div>\n</div>";
  };

  scrivito.editors.permalink_editor = {
    can_edit: function(element) {
      return $(element).is('[data-scrivito-field-name=_permalink]');
    },
    activate: function(element) {
      return activate(element);
    }
  };

  scrivito.on('load', function() {
    return scrivito.define_editor('permalink', scrivito.editors.permalink_editor);
  });

}).call(this);
